pub fn parse(pk11_uri: &str) -> Result<PK11URIMapping<'_>, PK11URIError>Expand description
Parses and verifies the contents of the given pk11_uri &str, making
parsed values available through a PK11URIMapping. Violations to RFC7512
specifications will result in issuing a PK11URIError.
The contents of the PK11URIMapping are string slices of the pk11_uri,
so if you need the mapping to outlive the pk11_uri, simply clone it.