pub struct PK11URIError { /* private fields */ }Expand description
Issued when parsing a PKCS#11 URI is found to be in violation of RFC7512 specifications.
The included pk11_uri is a “tidied” version of the one provided to the
parse function: any newline or tab formatting has been stripped out
in order to accurately identify the error_span within the uri. The violation
will refer to the RFC7512 Augmented BNF whenever possible, while the help
value provides a more human-friendly suggestion to correcting the violation.